@@ -32,17 +32,18 @@ const struct {
   char *otp;
   int expected_rc;
   int otp_pos;
+  uint64_t otp_counter;
 } tv[] = {
   /* Derived from RFC 6238. */
-  { 0, 10, "94287082", 1, 1},
-  { 1111111100, 10, "07081804", 0, 0},
-  { 1111111109, 10, "07081804", 0, 0},
-  { 1111111000, 10, "07081804", 3, 3},
-  { 1111112000, 99, "07081804", 30, -30},
-  { 1111111100, 10, "14050471", 1, 1},
-  { 1111111109, 10, "14050471", 1, 1},
-  { 1111111000, 10, "14050471", 4, 4},
-  { 1111112000, 99, "14050471", 29, -29},
+  { 0, 10, "94287082", 1, 1, 1},
+  { 1111111100, 10, "07081804", 0, 0, 37037036},
+  { 1111111109, 10, "07081804", 0, 0, 37037036},
+  { 1111111000, 10, "07081804", 3, 3, 37037036},
+  { 1111112000, 99, "07081804", 30, -30, 37037036},
+  { 1111111100, 10, "14050471", 1, 1, 37037037},
+  { 1111111109, 10, "14050471", 1, 1, 37037037},
+  { 1111111000, 10, "14050471", 4, 4, 37037037},
+  { 1111112000, 99, "14050471", 29, -29, 37037037},
 };
 /* *INDENT-ON* */
 
@@ -76,6 +77,7 @@ main (void)
   for (i = 0; i < sizeof (tv) / sizeof (tv[0]); i++)
     {
       int otp_pos;
+      uint64_t otp_counter;
 
       rc = oath_totp_validate (secret, secretlen, tv[i].now, time_step_size,
 			       start_offset, tv[i].window, tv[i].otp);
@@ -110,7 +112,7 @@ main (void)
 	}
       if (otp_pos != tv[i].otp_pos)
 	{
-	  printf ("validate2 loop %ld failed (cmp %d != %d)?!\n",
+	  printf ("validate2 loop %ld failed (pos %d != %d)?!\n",
 		  i, otp_pos, tv[i].otp_pos);
 	  return 1;
 	}
@@ -129,10 +131,63 @@ main (void)
 	}
       if (otp_pos != tv[i].otp_pos)
 	{
-	  printf ("validate2_callback loop %ld failed (cmp %d != %d)?!\n",
+	  printf ("validate2_callback loop %ld failed (pos %d != %d)?!\n",
 		  i, otp_pos, tv[i].otp_pos);
 	  return 1;
 	}
+
+      otp_pos = 95;
+      otp_counter = 23;
+
+      rc = oath_totp_validate3 (secret, secretlen, tv[i].now, time_step_size,
+				start_offset, tv[i].window, &otp_pos,
+				&otp_counter, tv[i].otp);
+      if (rc != tv[i].expected_rc)
+	{
+	  printf ("validate3 loop %ld failed (rc %d != %d)?!\n",
+		  i, rc, tv[i].expected_rc);
+	  return 1;
+	}
+      if (otp_pos != tv[i].otp_pos)
+	{
+	  printf ("validate3 loop %ld failed (pos %d != %d)?!\n",
+		  i, otp_pos, tv[i].otp_pos);
+	  return 1;
+	}
+      if (otp_counter != tv[i].otp_counter)
+	{
+	  printf ("validate3 loop %ld failed (counter %d != %d)?!\n",
+		  i, otp_counter, tv[i].otp_counter);
+	  return 1;
+	}
+
+      otp_pos = 191;
+      otp_counter = 47;
+
+      rc = oath_totp_validate3_callback (secret, secretlen, tv[i].now,
+					 time_step_size, start_offset,
+					 8, tv[i].window, &otp_pos,
+					 &otp_counter, my_strcmp,
+					 (void *) tv[i].otp);
+
+      if (rc != tv[i].expected_rc)
+	{
+	  printf ("validate3_callback loop %ld failed (rc %d != %d)?!\n",
+		  i, rc, tv[i].expected_rc);
+	  return 1;
+	}
+      if (otp_pos != tv[i].otp_pos)
+	{
+	  printf ("validate3_callback loop %ld failed (pos %d != %d)?!\n",
+		  i, otp_pos, tv[i].otp_pos);
+	  return 1;
+	}
+      if (otp_counter != tv[i].otp_counter)
+	{
+	  printf ("validate3_callback loop %ld failed (counter %d != %d)?!\n",
+		  i, otp_counter, tv[i].otp_counter);
+	  return 1;
+	}
     }
 
   rc = oath_done ();
