@@ -23,7 +23,7 @@
 
 #include <pskc/pskc.h>
 
-#include <string.h> /* memset */
+#include <string.h>		/* memset */
 
 #define INTERNAL_NEED_PSKC_STRUCT
 #define INTERNAL_NEED_PSKC_KEY_STRUCT
@@ -43,7 +43,7 @@
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_version (pskc_t *container)
+pskc_get_version (pskc_t * container)
 {
   return container->version;
 }
@@ -64,7 +64,7 @@ pskc_get_version (pskc_t *container)
  * Since: 2.2.0
  */
 void
-pskc_set_version (pskc_t *container, const char *version)
+pskc_set_version (pskc_t * container, const char *version)
 {
   container->version = version;
 }
@@ -79,7 +79,7 @@ pskc_set_version (pskc_t *container, const char *version)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_id (pskc_t *container)
+pskc_get_id (pskc_t * container)
 {
   return container->id;
 }
@@ -98,7 +98,7 @@ pskc_get_id (pskc_t *container)
  * Since: 2.2.0
  */
 void
-pskc_set_id (pskc_t *container, const char *id)
+pskc_set_id (pskc_t * container, const char *id)
 {
   container->id = id;
 }
@@ -114,7 +114,7 @@ pskc_set_id (pskc_t *container, const char *id)
  * element, 0 if there is no Signature element.
  */
 int
-pskc_get_signed_p (pskc_t *container)
+pskc_get_signed_p (pskc_t * container)
 {
   return container->signed_p;
 }
@@ -132,8 +132,7 @@ pskc_get_signed_p (pskc_t *container)
  *   #pskc_key_t pointer.
  */
 pskc_key_t *
-pskc_get_keypackage (pskc_t *container,
-		     size_t i)
+pskc_get_keypackage (pskc_t * container, size_t i)
 {
   if (i >= container->nkeypackages)
     return NULL;
@@ -154,7 +153,7 @@ pskc_get_keypackage (pskc_t *container,
  * Since: 2.2.0
  */
 int
-pskc_add_keypackage (pskc_t *container, pskc_key_t **key)
+pskc_add_keypackage (pskc_t * container, pskc_key_t ** key)
 {
   struct pskc_key *tmp;
 
@@ -185,7 +184,7 @@ pskc_add_keypackage (pskc_t *container, pskc_key_t **key)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_manufacturer (pskc_key_t *key)
+pskc_get_device_manufacturer (pskc_key_t * key)
 {
   return key->device_manufacturer;
 }
@@ -205,7 +204,7 @@ pskc_get_device_manufacturer (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_manufacturer (pskc_key_t *key, const char *devmfr)
+pskc_set_device_manufacturer (pskc_key_t * key, const char *devmfr)
 {
   key->device_manufacturer = devmfr;
 }
@@ -221,7 +220,7 @@ pskc_set_device_manufacturer (pskc_key_t *key, const char *devmfr)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_serialno (pskc_key_t *key)
+pskc_get_device_serialno (pskc_key_t * key)
 {
   return key->device_serialno;
 }
@@ -241,7 +240,7 @@ pskc_get_device_serialno (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_serialno (pskc_key_t *key, const char *serialno)
+pskc_set_device_serialno (pskc_key_t * key, const char *serialno)
 {
   key->device_serialno = serialno;
 }
@@ -258,7 +257,7 @@ pskc_set_device_serialno (pskc_key_t *key, const char *serialno)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_model (pskc_key_t *key)
+pskc_get_device_model (pskc_key_t * key)
 {
   return key->device_model;
 }
@@ -279,7 +278,7 @@ pskc_get_device_model (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_model (pskc_key_t *key, const char *model)
+pskc_set_device_model (pskc_key_t * key, const char *model)
 {
   key->device_model = model;
 }
@@ -297,7 +296,7 @@ pskc_set_device_model (pskc_key_t *key, const char *model)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_issueno (pskc_key_t *key)
+pskc_get_device_issueno (pskc_key_t * key)
 {
   return key->device_issueno;
 }
@@ -319,7 +318,7 @@ pskc_get_device_issueno (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_issueno (pskc_key_t *key, const char *issueno)
+pskc_set_device_issueno (pskc_key_t * key, const char *issueno)
 {
   key->device_issueno = issueno;
 }
@@ -341,7 +340,7 @@ pskc_set_device_issueno (pskc_key_t *key, const char *issueno)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_devicebinding (pskc_key_t *key)
+pskc_get_device_devicebinding (pskc_key_t * key)
 {
   return key->device_devicebinding;
 }
@@ -367,7 +366,7 @@ pskc_get_device_devicebinding (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_devicebinding (pskc_key_t *key, const char *devbind)
+pskc_set_device_devicebinding (pskc_key_t * key, const char *devbind)
 {
   key->device_devicebinding = devbind;
 }
@@ -384,7 +383,7 @@ pskc_set_device_devicebinding (pskc_key_t *key, const char *devbind)
  *   content, or NULL if not set.
  */
 const struct tm *
-pskc_get_device_startdate (pskc_key_t *key)
+pskc_get_device_startdate (pskc_key_t * key)
 {
   if (!key->device_startdate_str)
     return NULL;
@@ -403,7 +402,7 @@ pskc_get_device_startdate (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_startdate (pskc_key_t *key, const struct tm *startdate)
+pskc_set_device_startdate (pskc_key_t * key, const struct tm *startdate)
 {
   key->device_startdate_str = "set";
   memcpy (&key->device_startdate, startdate, sizeof (key->device_startdate));
@@ -421,7 +420,7 @@ pskc_set_device_startdate (pskc_key_t *key, const struct tm *startdate)
  *   content, or NULL if not set.
  */
 const struct tm *
-pskc_get_device_expirydate (pskc_key_t *key)
+pskc_get_device_expirydate (pskc_key_t * key)
 {
   if (!key->device_expirydate_str)
     return NULL;
@@ -440,10 +439,11 @@ pskc_get_device_expirydate (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_expirydate (pskc_key_t *key, const struct tm *expirydate)
+pskc_set_device_expirydate (pskc_key_t * key, const struct tm *expirydate)
 {
   key->device_expirydate_str = "set";
-  memcpy (&key->device_expirydate, expirydate, sizeof (key->device_expirydate));
+  memcpy (&key->device_expirydate, expirydate,
+	  sizeof (key->device_expirydate));
 }
 
 /**
@@ -457,7 +457,7 @@ pskc_set_device_expirydate (pskc_key_t *key, const struct tm *expirydate)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_device_userid (pskc_key_t *key)
+pskc_get_device_userid (pskc_key_t * key)
 {
   return key->device_userid;
 }
@@ -477,7 +477,7 @@ pskc_get_device_userid (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_device_userid (pskc_key_t *key, const char *userid)
+pskc_set_device_userid (pskc_key_t * key, const char *userid)
 {
   key->device_userid = userid;
 }
@@ -495,7 +495,7 @@ pskc_set_device_userid (pskc_key_t *key, const char *userid)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_cryptomodule_id (pskc_key_t *key)
+pskc_get_cryptomodule_id (pskc_key_t * key)
 {
   return key->cryptomodule_id;
 }
@@ -517,7 +517,7 @@ pskc_get_cryptomodule_id (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_cryptomodule_id (pskc_key_t *key, const char *cid)
+pskc_set_cryptomodule_id (pskc_key_t * key, const char *cid)
 {
   key->cryptomodule_id = cid;
 }
@@ -533,7 +533,7 @@ pskc_set_cryptomodule_id (pskc_key_t *key, const char *cid)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_id (pskc_key_t *key)
+pskc_get_key_id (pskc_key_t * key)
 {
   return key->key_id;
 }
@@ -553,7 +553,7 @@ pskc_get_key_id (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_id (pskc_key_t *key, const char *keyid)
+pskc_set_key_id (pskc_key_t * key, const char *keyid)
 {
   key->key_id = keyid;
 }
@@ -569,7 +569,7 @@ pskc_set_key_id (pskc_key_t *key, const char *keyid)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_algorithm (pskc_key_t *key)
+pskc_get_key_algorithm (pskc_key_t * key)
 {
   return key->key_algorithm;
 }
@@ -589,7 +589,7 @@ pskc_get_key_algorithm (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algorithm (pskc_key_t *key, const char *keyalg)
+pskc_set_key_algorithm (pskc_key_t * key, const char *keyalg)
 {
   key->key_algorithm = keyalg;
 }
@@ -604,7 +604,7 @@ pskc_set_key_algorithm (pskc_key_t *key, const char *keyalg)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_issuer (pskc_key_t *key)
+pskc_get_key_issuer (pskc_key_t * key)
 {
   return key->key_issuer;
 }
@@ -623,7 +623,7 @@ pskc_get_key_issuer (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_issuer (pskc_key_t *key, const char *keyissuer)
+pskc_set_key_issuer (pskc_key_t * key, const char *keyissuer)
 {
   key->key_issuer = keyissuer;
 }
@@ -638,7 +638,7 @@ pskc_set_key_issuer (pskc_key_t *key, const char *keyissuer)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_algparm_suite (pskc_key_t *key)
+pskc_get_key_algparm_suite (pskc_key_t * key)
 {
   return key->key_algparm_suite;
 }
@@ -657,7 +657,7 @@ pskc_get_key_algparm_suite (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_suite (pskc_key_t *key, const char *keyalgparmsuite)
+pskc_set_key_algparm_suite (pskc_key_t * key, const char *keyalgparmsuite)
 {
   key->key_algparm_suite = keyalgparmsuite;
 }
@@ -677,7 +677,7 @@ pskc_set_key_algparm_suite (pskc_key_t *key, const char *keyalgparmsuite)
  * Returns: an #pskc_valueformat value
  */
 pskc_valueformat
-pskc_get_key_algparm_chall_encoding (pskc_key_t *key, int *present)
+pskc_get_key_algparm_chall_encoding (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -702,7 +702,7 @@ pskc_get_key_algparm_chall_encoding (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_chall_encoding (pskc_key_t *key, pskc_valueformat vf)
+pskc_set_key_algparm_chall_encoding (pskc_key_t * key, pskc_valueformat vf)
 {
   key->key_algparm_chall_encoding_str = "set";
   key->key_algparm_chall_encoding = vf;
@@ -728,7 +728,7 @@ pskc_set_key_algparm_chall_encoding (pskc_key_t *key, pskc_valueformat vf)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_algparm_chall_min (pskc_key_t *key, int *present)
+pskc_get_key_algparm_chall_min (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -758,7 +758,7 @@ pskc_get_key_algparm_chall_min (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_chall_min (pskc_key_t *key, uint32_t challmin)
+pskc_set_key_algparm_chall_min (pskc_key_t * key, uint32_t challmin)
 {
   key->key_algparm_chall_min_str = "set";
   key->key_algparm_chall_min = challmin;
@@ -784,7 +784,7 @@ pskc_set_key_algparm_chall_min (pskc_key_t *key, uint32_t challmin)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_algparm_chall_max (pskc_key_t *key, int *present)
+pskc_get_key_algparm_chall_max (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -814,7 +814,7 @@ pskc_get_key_algparm_chall_max (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_chall_max (pskc_key_t *key, uint32_t challmax)
+pskc_set_key_algparm_chall_max (pskc_key_t * key, uint32_t challmax)
 {
   key->key_algparm_chall_max_str = "set";
   key->key_algparm_chall_max = challmax;
@@ -841,7 +841,7 @@ pskc_set_key_algparm_chall_max (pskc_key_t *key, uint32_t challmax)
  * indicate false.
  */
 int
-pskc_get_key_algparm_chall_checkdigits (pskc_key_t *key, int *present)
+pskc_get_key_algparm_chall_checkdigits (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -871,7 +871,7 @@ pskc_get_key_algparm_chall_checkdigits (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_chall_checkdigits (pskc_key_t *key, int checkdigit)
+pskc_set_key_algparm_chall_checkdigits (pskc_key_t * key, int checkdigit)
 {
   key->key_algparm_chall_checkdigits_str = "set";
   key->key_algparm_chall_checkdigits = checkdigit ? 1 : 0;
@@ -892,7 +892,7 @@ pskc_set_key_algparm_chall_checkdigits (pskc_key_t *key, int checkdigit)
  * Returns: an #pskc_valueformat value
  */
 pskc_valueformat
-pskc_get_key_algparm_resp_encoding (pskc_key_t *key, int *present)
+pskc_get_key_algparm_resp_encoding (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -917,7 +917,7 @@ pskc_get_key_algparm_resp_encoding (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_resp_encoding (pskc_key_t *key, pskc_valueformat vf)
+pskc_set_key_algparm_resp_encoding (pskc_key_t * key, pskc_valueformat vf)
 {
   key->key_algparm_resp_encoding_str = "set";
   key->key_algparm_resp_encoding = vf;
@@ -942,7 +942,7 @@ pskc_set_key_algparm_resp_encoding (pskc_key_t *key, pskc_valueformat vf)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_algparm_resp_length (pskc_key_t *key, int *present)
+pskc_get_key_algparm_resp_length (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -971,7 +971,7 @@ pskc_get_key_algparm_resp_length (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_resp_length (pskc_key_t *key, uint32_t length)
+pskc_set_key_algparm_resp_length (pskc_key_t * key, uint32_t length)
 {
   key->key_algparm_resp_length_str = "set";
   key->key_algparm_resp_length = length;
@@ -997,7 +997,7 @@ pskc_set_key_algparm_resp_length (pskc_key_t *key, uint32_t length)
  * indicate false.
  */
 int
-pskc_get_key_algparm_resp_checkdigits (pskc_key_t *key, int *present)
+pskc_get_key_algparm_resp_checkdigits (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1026,7 +1026,7 @@ pskc_get_key_algparm_resp_checkdigits (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_algparm_resp_checkdigits (pskc_key_t *key, int checkdigit)
+pskc_set_key_algparm_resp_checkdigits (pskc_key_t * key, int checkdigit)
 {
   key->key_algparm_resp_checkdigits_str = "set";
   key->key_algparm_resp_checkdigits = checkdigit ? 1 : 0;
@@ -1042,7 +1042,7 @@ pskc_set_key_algparm_resp_checkdigits (pskc_key_t *key, int checkdigit)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_profileid (pskc_key_t *key)
+pskc_get_key_profileid (pskc_key_t * key)
 {
   return key->key_profileid;
 }
@@ -1061,7 +1061,7 @@ pskc_get_key_profileid (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_profileid (pskc_key_t *key, const char *profileid)
+pskc_set_key_profileid (pskc_key_t * key, const char *profileid)
 {
   key->key_profileid = profileid;
 }
@@ -1076,7 +1076,7 @@ pskc_set_key_profileid (pskc_key_t *key, const char *profileid)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_reference (pskc_key_t *key)
+pskc_get_key_reference (pskc_key_t * key)
 {
   return key->key_reference;
 }
@@ -1095,7 +1095,7 @@ pskc_get_key_reference (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_reference (pskc_key_t *key, const char *keyref)
+pskc_set_key_reference (pskc_key_t * key, const char *keyref)
 {
   key->key_reference = keyref;
 }
@@ -1110,7 +1110,7 @@ pskc_set_key_reference (pskc_key_t *key, const char *keyref)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_friendlyname (pskc_key_t *key)
+pskc_get_key_friendlyname (pskc_key_t * key)
 {
   return key->key_friendlyname;
 }
@@ -1129,7 +1129,7 @@ pskc_get_key_friendlyname (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_friendlyname (pskc_key_t *key, const char *fname)
+pskc_set_key_friendlyname (pskc_key_t * key, const char *fname)
 {
   key->key_friendlyname = fname;
 }
@@ -1144,7 +1144,7 @@ pskc_set_key_friendlyname (pskc_key_t *key, const char *fname)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_userid (pskc_key_t *key)
+pskc_get_key_userid (pskc_key_t * key)
 {
   return key->key_userid;
 }
@@ -1163,7 +1163,7 @@ pskc_get_key_userid (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_userid (pskc_key_t *key, const char *keyuserid)
+pskc_set_key_userid (pskc_key_t * key, const char *keyuserid)
 {
   key->key_userid = keyuserid;
 }
@@ -1181,8 +1181,7 @@ pskc_set_key_userid (pskc_key_t *key, const char *keyuserid)
  *   content of length *@len, or NULL if not set.
  */
 const char *
-pskc_get_key_data_secret (pskc_key_t *key,
-			  size_t *len)
+pskc_get_key_data_secret (pskc_key_t * key, size_t * len)
 {
   if (len)
     *len = key->key_secret_len;
@@ -1208,7 +1207,7 @@ pskc_get_key_data_secret (pskc_key_t *key,
  * Since: 2.2.0
  */
 int
-pskc_set_key_data_secret (pskc_key_t *key, const char *data, size_t len)
+pskc_set_key_data_secret (pskc_key_t * key, const char *data, size_t len)
 {
   char *out, *datacopy;
 
@@ -1246,7 +1245,7 @@ pskc_set_key_data_secret (pskc_key_t *key, const char *data, size_t len)
  *   content of length *@len, or NULL if not set.
  */
 const char *
-pskc_get_key_data_b64secret (pskc_key_t *key)
+pskc_get_key_data_b64secret (pskc_key_t * key)
 {
   return key->key_b64secret;
 }
@@ -1270,7 +1269,7 @@ pskc_get_key_data_b64secret (pskc_key_t *key)
  * Since: 2.2.0
  */
 int
-pskc_set_key_data_b64secret (pskc_key_t *key, const char *b64secret)
+pskc_set_key_data_b64secret (pskc_key_t * key, const char *b64secret)
 {
   size_t l = strlen (b64secret);
   char *out, *b64copy;
@@ -1320,7 +1319,7 @@ pskc_set_key_data_b64secret (pskc_key_t *key, const char *b64secret)
  * Returns: an integer holding the content.
  */
 uint64_t
-pskc_get_key_data_counter (pskc_key_t *key, int *present)
+pskc_get_key_data_counter (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1344,7 +1343,7 @@ pskc_get_key_data_counter (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_data_counter (pskc_key_t *key, uint64_t counter)
+pskc_set_key_data_counter (pskc_key_t * key, uint64_t counter)
 {
   key->key_counter_str = "set";
   key->key_counter = counter;
@@ -1366,7 +1365,7 @@ pskc_set_key_data_counter (pskc_key_t *key, uint64_t counter)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_data_time (pskc_key_t *key, int *present)
+pskc_get_key_data_time (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1392,7 +1391,7 @@ pskc_get_key_data_time (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_data_time (pskc_key_t *key, uint32_t datatime)
+pskc_set_key_data_time (pskc_key_t * key, uint32_t datatime)
 {
   key->key_time_str = "set";
   key->key_time = datatime;
@@ -1414,7 +1413,7 @@ pskc_set_key_data_time (pskc_key_t *key, uint32_t datatime)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_data_timeinterval (pskc_key_t *key, int *present)
+pskc_get_key_data_timeinterval (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1440,7 +1439,7 @@ pskc_get_key_data_timeinterval (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_data_timeinterval (pskc_key_t *key, uint32_t timeinterval)
+pskc_set_key_data_timeinterval (pskc_key_t * key, uint32_t timeinterval)
 {
   key->key_timeinterval_str = "set";
   key->key_timeinterval = timeinterval;
@@ -1467,7 +1466,7 @@ pskc_set_key_data_timeinterval (pskc_key_t *key, uint32_t timeinterval)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_data_timedrift (pskc_key_t *key, int *present)
+pskc_get_key_data_timedrift (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1498,7 +1497,7 @@ pskc_get_key_data_timedrift (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_data_timedrift (pskc_key_t *key, uint32_t timedrift)
+pskc_set_key_data_timedrift (pskc_key_t * key, uint32_t timedrift)
 {
   key->key_timedrift_str = "set";
   key->key_timedrift = timedrift;
@@ -1515,7 +1514,7 @@ pskc_set_key_data_timedrift (pskc_key_t *key, uint32_t timedrift)
  *   content, or NULL if not set.
  */
 const struct tm *
-pskc_get_key_policy_startdate (pskc_key_t *key)
+pskc_get_key_policy_startdate (pskc_key_t * key)
 {
   if (!key->key_policy_startdate_str)
     return NULL;
@@ -1533,7 +1532,7 @@ pskc_get_key_policy_startdate (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_startdate (pskc_key_t *key, const struct tm *startdate)
+pskc_set_key_policy_startdate (pskc_key_t * key, const struct tm *startdate)
 {
   key->key_policy_startdate_str = "set";
   memcpy (&key->key_policy_startdate, startdate,
@@ -1551,7 +1550,7 @@ pskc_set_key_policy_startdate (pskc_key_t *key, const struct tm *startdate)
  *   content, or NULL if not set.
  */
 const struct tm *
-pskc_get_key_policy_expirydate (pskc_key_t *key)
+pskc_get_key_policy_expirydate (pskc_key_t * key)
 {
   if (!key->key_policy_expirydate_str)
     return NULL;
@@ -1569,7 +1568,7 @@ pskc_get_key_policy_expirydate (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_expirydate (pskc_key_t *key, const struct tm *expirydate)
+pskc_set_key_policy_expirydate (pskc_key_t * key, const struct tm *expirydate)
 {
   key->key_policy_expirydate_str = "set";
   memcpy (&key->key_policy_expirydate, expirydate,
@@ -1589,7 +1588,7 @@ pskc_set_key_policy_expirydate (pskc_key_t *key, const struct tm *expirydate)
  *   content, or NULL if not set.
  */
 const char *
-pskc_get_key_policy_pinkeyid (pskc_key_t *key)
+pskc_get_key_policy_pinkeyid (pskc_key_t * key)
 {
   return key->key_policy_pinkeyid;
 }
@@ -1611,7 +1610,7 @@ pskc_get_key_policy_pinkeyid (pskc_key_t *key)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinkeyid (pskc_key_t *key, const char *pinkeyid)
+pskc_set_key_policy_pinkeyid (pskc_key_t * key, const char *pinkeyid)
 {
   key->key_policy_pinkeyid = pinkeyid;
 }
@@ -1631,7 +1630,7 @@ pskc_set_key_policy_pinkeyid (pskc_key_t *key, const char *pinkeyid)
  * Returns: an #pskc_pinusagemode value
  */
 pskc_pinusagemode
-pskc_get_key_policy_pinusagemode (pskc_key_t *key, int *present)
+pskc_get_key_policy_pinusagemode (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1656,7 +1655,7 @@ pskc_get_key_policy_pinusagemode (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinusagemode (pskc_key_t *key,
+pskc_set_key_policy_pinusagemode (pskc_key_t * key,
 				  pskc_pinusagemode pinusagemode)
 {
   key->key_policy_pinusagemode_str = "set";
@@ -1680,7 +1679,7 @@ pskc_set_key_policy_pinusagemode (pskc_key_t *key,
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_policy_pinmaxfailedattempts (pskc_key_t *key, int *present)
+pskc_get_key_policy_pinmaxfailedattempts (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1707,7 +1706,7 @@ pskc_get_key_policy_pinmaxfailedattempts (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinmaxfailedattempts (pskc_key_t *key, uint32_t attempts)
+pskc_set_key_policy_pinmaxfailedattempts (pskc_key_t * key, uint32_t attempts)
 {
   key->key_policy_pinmaxfailedattempts_str = "set";
   key->key_policy_pinmaxfailedattempts = attempts;
@@ -1733,7 +1732,7 @@ pskc_set_key_policy_pinmaxfailedattempts (pskc_key_t *key, uint32_t attempts)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_policy_pinminlength (pskc_key_t *key, int *present)
+pskc_get_key_policy_pinminlength (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1763,7 +1762,7 @@ pskc_get_key_policy_pinminlength (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinminlength (pskc_key_t *key, uint32_t minlength)
+pskc_set_key_policy_pinminlength (pskc_key_t * key, uint32_t minlength)
 {
   key->key_policy_pinminlength_str = "set";
   key->key_policy_pinminlength = minlength;
@@ -1789,7 +1788,7 @@ pskc_set_key_policy_pinminlength (pskc_key_t *key, uint32_t minlength)
  * Returns: an integer holding the content.
  */
 uint32_t
-pskc_get_key_policy_pinmaxlength (pskc_key_t *key, int *present)
+pskc_get_key_policy_pinmaxlength (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1819,7 +1818,7 @@ pskc_get_key_policy_pinmaxlength (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinmaxlength (pskc_key_t *key, uint32_t maxlength)
+pskc_set_key_policy_pinmaxlength (pskc_key_t * key, uint32_t maxlength)
 {
   key->key_policy_pinmaxlength_str = "set";
   key->key_policy_pinmaxlength = maxlength;
@@ -1840,7 +1839,7 @@ pskc_set_key_policy_pinmaxlength (pskc_key_t *key, uint32_t maxlength)
  * Returns: an #pskc_valueformat value
  */
 pskc_valueformat
-pskc_get_key_policy_pinencoding (pskc_key_t *key, int *present)
+pskc_get_key_policy_pinencoding (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1865,7 +1864,8 @@ pskc_get_key_policy_pinencoding (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_pinencoding (pskc_key_t *key, pskc_valueformat pinencoding)
+pskc_set_key_policy_pinencoding (pskc_key_t * key,
+				 pskc_valueformat pinencoding)
 {
   key->key_policy_pinencoding_str = "set";
   key->key_policy_pinencoding = pinencoding;
@@ -1887,7 +1887,7 @@ pskc_set_key_policy_pinencoding (pskc_key_t *key, pskc_valueformat pinencoding)
  * together.
  */
 int
-pskc_get_key_policy_keyusages (pskc_key_t *key, int *present)
+pskc_get_key_policy_keyusages (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1912,7 +1912,7 @@ pskc_get_key_policy_keyusages (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_keyusages (pskc_key_t *key, int keyusages)
+pskc_set_key_policy_keyusages (pskc_key_t * key, int keyusages)
 {
   key->key_policy_keyusage_str = "set";
   key->key_policy_keyusages = keyusages;
@@ -1939,7 +1939,7 @@ pskc_set_key_policy_keyusages (pskc_key_t *key, int keyusages)
  * Returns: an integer holding the content.
  */
 uint64_t
-pskc_get_key_policy_numberoftransactions (pskc_key_t *key, int *present)
+pskc_get_key_policy_numberoftransactions (pskc_key_t * key, int *present)
 {
   if (present)
     {
@@ -1970,7 +1970,7 @@ pskc_get_key_policy_numberoftransactions (pskc_key_t *key, int *present)
  * Since: 2.2.0
  */
 void
-pskc_set_key_policy_numberoftransactions (pskc_key_t *key, uint64_t uses)
+pskc_set_key_policy_numberoftransactions (pskc_key_t * key, uint64_t uses)
 {
   key->key_policy_numberoftransactions_str = "set";
   key->key_policy_numberoftransactions = uses;
